<?php
/**
 * Implement theme metabox.
 *
 * @package Blog Expert
 */

if (!function_exists('blog_expert_add_theme_meta_box')) :

    /**
     * Add the Meta Box
     *
     * @since 1.0.0
     */
    function blog_expert_add_theme_meta_box()
    {

        $apply_metabox_post_types = array('post', 'page');

        foreach ($apply_metabox_post_types as $key => $type) {
            add_meta_box(
                'blog-expert-theme-settings',
                esc_html__('Single Page/Post Settings', 'blog-expert'),
                'blog_expert_render_theme_settings_metabox',
                $type
            );
        }

    }

endif;

add_action('add_meta_boxes', 'blog_expert_add_theme_meta_box');

add_action( 'admin_enqueue_scripts', 'blog_expert_backend_scripts');
if ( ! function_exists( 'blog_expert_backend_scripts' ) ){
    function blog_expert_backend_scripts( $hook ) {
        wp_enqueue_style( 'wp-color-picker');
        wp_enqueue_script( 'wp-color-picker');
    }
}

if (!function_exists('blog_expert_render_theme_settings_metabox')) :

    /**
     * Render theme settings meta box.
     *
     * @since 1.0.0
     */
    function blog_expert_render_theme_settings_metabox($post, $metabox)
    {

        $post_id = $post->ID;
        $blog_expert_post_meta_value = get_post_meta($post_id);

        // Meta box nonce for verification.
        wp_nonce_field(basename(__FILE__), 'blog_expert_meta_box_nonce');
        // Fetch Options list.
        $page_layout = get_post_meta($post_id, 'blog-expert-meta-select-layout', true);
        $page_image_layout = get_post_meta($post_id, 'blog-expert-meta-image-layout', true);
        $blog_expert_meta_checkbox = get_post_meta($post_id, 'blog-expert-meta-checkbox', true);
        ?>

        <div class="expert-tab-main">

            <div class="expert-metabox-tab">
                <ul>
                    <li>
                        <a id="twp-tab-general" class="twp-tab-active" href="javascript:void(0)"><?php esc_html_e('Layout Settings', 'blog-expert'); ?></a>
                    </li>
                </ul>
            </div>

            <div class="expert-tab-content">
                
                <div id="twp-tab-general-content" class="expert-content-wrap expert-tab-content-active">

                    <div class="expert-meta-panels">

                        <div class="expert-opt-wrap expert-checkbox-wrap">

                            <input id="feature-image-checkbox" name="blog-expert-meta-checkbox" type="checkbox" <?php if ($blog_expert_meta_checkbox) { ?> checked="checked" <?php } ?> />

                            <label for="feature-image-checkbox"><?php esc_html_e('Check To Use Featured Image As Banner Image', 'blog-expert'); ?></label>
                        </div>

                         <div class="expert-opt-wrap expert-opt-wrap-alt">
                            <label><?php esc_html_e('Single Page/Post Layout', 'blog-expert'); ?></label>
                            <select name="blog-expert-meta-select-layout" id="blog-expert-meta-select-layout">

                                <option value="global" <?php selected('global', $page_layout); ?>>
                                    <?php esc_html_e('Global', 'blog-expert') ?>
                                </option>

                                <option value="right-sidebar" <?php selected('right-sidebar', $page_layout); ?>>
                                    <?php esc_html_e('Content - Primary Sidebar', 'blog-expert') ?>
                                </option>
                                <option value="left-sidebar" <?php selected('left-sidebar', $page_layout); ?>>
                                    <?php esc_html_e('Primary Sidebar - Content', 'blog-expert') ?>
                                </option>
                                <option value="no-sidebar" <?php selected('no-sidebar', $page_layout); ?>>
                                    <?php esc_html_e('No Sidebar', 'blog-expert') ?>
                                </option>
                            </select>
                        </div>

                        <div class="expert-opt-wrap expert-opt-wrap-alt">
                            <label><?php esc_html_e('Single Page/Post Image Layout', 'blog-expert'); ?></label>
                            <select name="blog-expert-meta-image-layout" id="blog-expert-meta-image-layout">

                                <option value="global" <?php selected('global', $page_layout); ?>>
                                    <?php esc_html_e('Global', 'blog-expert') ?>
                                </option>

                                <option value="full" <?php selected('full', $page_image_layout); ?>>
                                    <?php esc_html_e('Full', 'blog-expert') ?>
                                </option>
                                <option value="left" <?php selected('left', $page_image_layout); ?>>
                                    <?php esc_html_e('Left', 'blog-expert') ?>
                                </option>
                                <option value="right" <?php selected('right', $page_image_layout); ?>>
                                    <?php esc_html_e('Right', 'blog-expert') ?>
                                </option>
                                <option value="no-image" <?php selected('no-image', $page_image_layout); ?>>
                                    <?php esc_html_e('No Image', 'blog-expert') ?>
                                </option>
                            </select>
                        </div>


                    </div>
                </div>

            </div>
        </div>

        <?php
    }

endif;


if (!function_exists('blog_expert_save_theme_settings_meta')) :

    /**
     * Save theme settings meta box value.
     *
     * @since 1.0.0
     *
     * @param int $post_id Post ID.
     * @param WP_Post $post Post object.
     */
    function blog_expert_save_theme_settings_meta($post_id, $post)
    {

        // Verify nonce.
        if( !isset( $_POST['blog_expert_meta_box_nonce'] ) || !wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['blog_expert_meta_box_nonce'] ) ), basename(__FILE__) ) ) {
            return;
        }

        // Bail if auto save or revision.
        if( defined('DOING_AUTOSAVE') || is_int( wp_is_post_revision( $post ) ) || is_int( wp_is_post_autosave( $post ) ) ) {
            return;
        }

        // Check the post being saved == the $post_id to prevent triggering this call for other save_post events.
        if (!isset( $_POST['post_ID'] ) || empty($_POST['post_ID']) || absint( wp_unslash( $_POST['post_ID'] ) ) != absint( $post_id ) ) {
            return;
        }

        // Check permission.
        if ( isset( $_POST['post_type'] ) && 'page' === $_POST['post_type'] ) {
            if (!current_user_can('edit_page', $post_id)) {
                return;
            }
        } else if (!current_user_can('edit_post', $post_id)) {
            return;
        }

        $blog_expert_meta_checkbox = isset($_POST['blog-expert-meta-checkbox']) ? sanitize_text_field( wp_unslash( $_POST['blog-expert-meta-checkbox'] ) ) : '';
        update_post_meta($post_id, 'blog-expert-meta-checkbox', sanitize_text_field($blog_expert_meta_checkbox));

        $blog_expert_meta_select_layout = isset($_POST['blog-expert-meta-select-layout']) ? sanitize_text_field( wp_unslash( $_POST['blog-expert-meta-select-layout'] ) ) : '';
        if (!empty($blog_expert_meta_select_layout)) {
            update_post_meta($post_id, 'blog-expert-meta-select-layout', sanitize_text_field($blog_expert_meta_select_layout));
        }
        $blog_expert_meta_image_layout = isset($_POST['blog-expert-meta-image-layout']) ? sanitize_text_field( wp_unslash( $_POST['blog-expert-meta-image-layout'] ) ) : '';
        if (!empty($blog_expert_meta_image_layout)) {
            update_post_meta($post_id, 'blog-expert-meta-image-layout', sanitize_text_field($blog_expert_meta_image_layout));
        }

    }

endif;

add_action('save_post', 'blog_expert_save_theme_settings_meta', 10, 3);